@@ -168,7 +168,7 @@ class FontPAMC:
         self.nextoffset = 0
 
 
-def readNFTR(file, generateglyphs=False):
+def readNFTR(file, generateglyphs=False, encoding="shift_jis"):
     nftr = FontNFTR()
     with common.Stream(file, "rb") as f:
         # Header
@@ -263,7 +263,7 @@ def readNFTR(file, generateglyphs=False):
             if pamc.type == 0:
                 firstcode = f.readUShort()
                 for i in range(pamc.lastchar - pamc.firstchar + 1):
-                    c = common.codeToChar(pamc.firstchar + i)
+                    c = common.codeToChar(pamc.firstchar + i, encoding)
                     hdwc = nftr.hdwc[firstcode + i]
                     nftr.glyphs[c] = common.FontGlyph(hdwc.start, hdwc.width, hdwc.length, c, pamc.firstchar + i, firstcode + i)
             elif pamc.type == 1:
@@ -271,9 +271,17 @@ def readNFTR(file, generateglyphs=False):
                     charcode = f.readUShort()
                     if charcode == 0xFFFF or charcode >= len(nftr.hdwc):
                         continue
-                    c = common.codeToChar(pamc.firstchar + i)
+                    c = common.codeToChar(pamc.firstchar + i, encoding)
                     hdwc = nftr.hdwc[charcode]
                     nftr.glyphs[c] = common.FontGlyph(hdwc.start, hdwc.width, hdwc.length, c, pamc.firstchar + i, charcode)
+            elif pamc.type == 2:
+                groupnum = f.readUShort()
+                for i in range(groupnum - pamc.firstchar):
+                    charcode = f.readUShort()
+                    c = common.codeToChar(charcode, encoding)
+                    tilenum = f.readUShort()
+                    hdwc = nftr.hdwc[tilenum]
+                    nftr.glyphs[c] = common.FontGlyph(hdwc.start, hdwc.width, hdwc.length, c,  charcode, tilenum)
             else:
                 common.logWarning("Unknown section type", pamc.type)
     return nftr
@@ -1018,6 +1026,7 @@ def writeNSCR(file, ncgr, nscr, infile, palettes, width=-1, height=-1):
                 map = nscr.maps[x]
                 # Skip flipped tiles since there's always(?) going to be an unflipped one next
                 if map.xflip or map.yflip:
+                    x += 1
                     continue
                 # Write the tile if it's a new one
                 if map.tile not in donetiles:
