@@ -1,6 +1,6 @@
 import pytest
 import os.path
-from hacktools import cmp_lzss, cmp_cri
+from hacktools import cmp_lzss, cmp_cri, cmp_racjin
 
 @pytest.fixture
 def data():
@@ -28,3 +28,10 @@ def test_cmp_cri(data):
     decmp = cmp_cri.decompressCRILAYLA(cmp)
     assert len(data) == len(decmp)
     assert data == decmp
+
+
+def test_cmp_racjin(data):
+    cmp = cmp_racjin.compressRACJIN(data)
+    decmp = cmp_racjin.decompressRACJIN(cmp, len(data))
+    assert len(data) == len(decmp)
+    assert data == decmp
